# File list for template-set {{ set_name }}
- FILE_NAME: "{% raw %}{{ PROJ.ROOT }}/greeting.txt.j2{% endraw %}"
  RENDERED_FILE_NAME: "{{ PROJ.ROOT }}/greeting.txt"
  PROCESS_TYPE: COPY
  PROCESS_TYPE: "COPY"
  EXTRAS:
    PURPOSE: "Blank __init__"
    DESCRIPTION: "Blank __init__"
    REQUIREMENTS: []
    DEPENDENCIES: []

- FILE_NAME: "{% raw %}{{ PROJ.ROOT }}/hello.txt.j2{% endraw %}"
  RENDERED_FILE_NAME: "{{ PROJ.ROOT }}/hello.txt"
  PROCESS_TYPE: COPY
  PROCESS_TYPE: "COPY"
  EXTRAS:
    PURPOSE: "Blank __init__"
    DESCRIPTION: "Blank __init__"
    REQUIREMENTS: []
    DEPENDENCIES: []