// File: {{ MOD.NAME }}.a11y.spec.ts.j2

import React from 'react';
import { render } from '@testing-library/react';
import { axe, toHaveNoViolations } from 'jest-axe';
import {{ MOD.NAME }} from './{{  MOD.NAME }}.tsx';

